import type { ExecutionBaseError, IConnection, IExecuteData, INode, INodeExecutionData, IPinData, IRun, IRunData, Workflow, IRunExecutionData, IWorkflowExecuteAdditionalData, WorkflowExecuteMode, StartNodeData, IRunNodeResponse, IWorkflowIssues } from 'n8n-workflow';
import PCancelable from 'p-cancelable';
export declare class WorkflowExecute {
    private readonly additionalData;
    private readonly mode;
    private runExecutionData;
    private status;
    private readonly abortController;
    constructor(additionalData: IWorkflowExecuteAdditionalData, mode: WorkflowExecuteMode, runExecutionData?: IRunExecutionData);
    run(workflow: Workflow, startNode?: INode, destinationNode?: string, pinData?: IPinData): PCancelable<IRun>;
    forceInputNodeExecution(workflow: Workflow): boolean;
    runPartialWorkflow(workflow: Workflow, runData: IRunData, startNodes: StartNodeData[], destinationNode?: string, pinData?: IPinData): PCancelable<IRun>;
    runPartialWorkflow2(workflow: Workflow, runData: IRunData, pinData?: IPinData, dirtyNodeNames?: string[], destinationNodeName?: string): PCancelable<IRun>;
    executeHook(hookName: string, parameters: any[]): Promise<void>;
    moveNodeMetadata(): void;
    incomingConnectionIsEmpty(runData: IRunData, inputConnections: IConnection[], runIndex: number): boolean;
    prepareWaitingToExecution(nodeName: string, numberOfConnections: number, runIndex: number): void;
    addNodeToBeExecuted(workflow: Workflow, connectionData: IConnection, outputIndex: number, parentNodeName: string, nodeSuccessData: INodeExecutionData[][], runIndex: number): void;
    checkReadyForExecution(workflow: Workflow, inputData?: {
        startNode?: string;
        destinationNode?: string;
        pinDataNodeNames?: string[];
    }): IWorkflowIssues | null;
    runNode(workflow: Workflow, executionData: IExecuteData, runExecutionData: IRunExecutionData, runIndex: number, additionalData: IWorkflowExecuteAdditionalData, mode: WorkflowExecuteMode, abortSignal?: AbortSignal): Promise<IRunNodeResponse>;
    processRunExecutionData(workflow: Workflow): PCancelable<IRun>;
    processSuccessExecution(startedAt: Date, workflow: Workflow, executionError?: ExecutionBaseError, closeFunction?: Promise<void>): Promise<IRun>;
    getFullRunData(startedAt: Date): IRun;
    private get isCancelled();
}
