"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ErrorReporter = void 0;
const node_1 = require("@sentry/node");
const axios_1 = require("axios");
const n8n_workflow_1 = require("n8n-workflow");
const node_crypto_1 = require("node:crypto");
const typedi_1 = require("typedi");
let ErrorReporter = class ErrorReporter {
    constructor() {
        this.seenErrors = new Set();
        this.report = this.defaultReport;
    }
    defaultReport(error, options) {
        if (error instanceof Error) {
            let e = error;
            const { executionId } = options ?? {};
            const context = executionId ? ` (execution ${executionId})` : '';
            do {
                const msg = [e.message + context, e.stack ? `\n${e.stack}\n` : ''].join('');
                const meta = e instanceof n8n_workflow_1.ApplicationError ? e.extra : undefined;
                n8n_workflow_1.LoggerProxy.error(msg, meta);
                e = e.cause;
            } while (e);
        }
    }
    async shutdown(timeoutInMs = 1000) {
        await (0, node_1.close)(timeoutInMs);
    }
    async init(instanceType, dsn) {
        process.on('uncaughtException', (error) => {
            this.error(error);
        });
        if (!dsn)
            return;
        Error.stackTraceLimit = 50;
        const { N8N_VERSION: release, ENVIRONMENT: environment, DEPLOYMENT_NAME: serverName, } = process.env;
        const { init, captureException, setTag } = await Promise.resolve().then(() => __importStar(require('@sentry/node')));
        const { requestDataIntegration, rewriteFramesIntegration } = await Promise.resolve().then(() => __importStar(require('@sentry/node')));
        const enabledIntegrations = [
            'InboundFilters',
            'FunctionToString',
            'LinkedErrors',
            'OnUnhandledRejection',
            'ContextLines',
        ];
        init({
            dsn,
            release,
            environment,
            enableTracing: false,
            serverName,
            beforeBreadcrumb: () => null,
            beforeSend: this.beforeSend.bind(this),
            integrations: (integrations) => [
                ...integrations.filter(({ name }) => enabledIntegrations.includes(name)),
                rewriteFramesIntegration({ root: process.cwd() }),
                requestDataIntegration({
                    include: {
                        cookies: false,
                        data: false,
                        headers: false,
                        query_string: false,
                        url: true,
                        user: false,
                    },
                }),
            ],
        });
        setTag('server_type', instanceType);
        this.report = (error, options) => captureException(error, options);
    }
    async beforeSend(event, { originalException }) {
        if (!originalException)
            return null;
        if (originalException instanceof Promise) {
            originalException = await originalException.catch((error) => error);
        }
        if (originalException instanceof axios_1.AxiosError)
            return null;
        if (originalException instanceof Error &&
            originalException.name === 'QueryFailedError' &&
            ['SQLITE_FULL', 'SQLITE_IOERR'].some((errMsg) => originalException.message.includes(errMsg))) {
            return null;
        }
        if (originalException instanceof n8n_workflow_1.ApplicationError) {
            const { level, extra, tags } = originalException;
            if (level === 'warning')
                return null;
            event.level = level;
            if (extra)
                event.extra = { ...event.extra, ...extra };
            if (tags)
                event.tags = { ...event.tags, ...tags };
        }
        if (originalException instanceof Error &&
            'cause' in originalException &&
            originalException.cause instanceof Error &&
            'level' in originalException.cause &&
            originalException.cause.level === 'warning') {
            return null;
        }
        if (originalException instanceof Error && originalException.stack) {
            const eventHash = (0, node_crypto_1.createHash)('sha1').update(originalException.stack).digest('base64');
            if (this.seenErrors.has(eventHash))
                return null;
            this.seenErrors.add(eventHash);
        }
        return event;
    }
    error(e, options) {
        const toReport = this.wrap(e);
        if (toReport)
            this.report(toReport, options);
    }
    warn(warning, options) {
        this.error(warning, { ...options, level: 'warning' });
    }
    info(msg, options) {
        this.report(msg, { ...options, level: 'info' });
    }
    wrap(e) {
        if (e instanceof Error)
            return e;
        if (typeof e === 'string')
            return new n8n_workflow_1.ApplicationError(e);
        return;
    }
};
exports.ErrorReporter = ErrorReporter;
exports.ErrorReporter = ErrorReporter = __decorate([
    (0, typedi_1.Service)(),
    __metadata("design:paramtypes", [])
], ErrorReporter);
//# sourceMappingURL=error-reporter.js.map